@@ -3,7 +3,7 @@
 # Filename: AutoInit_GBase8s.sh
 # Function: Auto install GBase 8s software and auto init database.
 # Write by: liaojinqing@gbase.cn
-# Version : 1.4.0   update date: 2022-01-11
+# Version : 1.4.1.1   update date: 2022-07-27
 ##################################################################
 ##### Defind env
 export LANG=C
@@ -275,6 +275,7 @@ loginfo "Building $CFGFILE ."
 sed -i "s#^ROOTPATH.*#ROOTPATH $DATADIR/rootchk#g" $CFGFILE
 sed -i "s#^ROOTSIZE.*#ROOTSIZE $ROOTSIZE#g" $CFGFILE
 sed -i "s#^DBSERVERNAME.*#DBSERVERNAME $GBASESERVER#g" $CFGFILE
+sed -i "s#^TAPEDEV.*#TAPEDEV /dev/null#g" $CFGFILE
 sed -i "s#^LTAPEDEV.*#LTAPEDEV /dev/null#g" $CFGFILE
 sed -i "s#^USERMAPPING.*#USERMAPPING ADMIN#g" $CFGFILE
 sed -i "s#^DEF_TABLE_LOCKMODE.*#DEF_TABLE_LOCKMODE row#g" $CFGFILE
