@@ -3,7 +3,7 @@
 # Filename: CleanAll.sh
 # Function: Clean GBase 8s Auto Install.
 # Write by: liaojinqing@gbase.cn
-# Version : 1.3.11   update date: 2021-03-18
+# Version : 1.4.0   update date: 2022-01-11
 ##################################################################
 ##### Define Parameter
 ##### Get Parameter
@@ -28,10 +28,17 @@ Usage:
 done
 
 USER_NAME=${USER_NAME:-gbasedbt}
-INSTALL_DIR=/opt/gbase
 WORKDIR=$(pwd)
 
 #### do clean
+id ${USER_NAME} >/dev/null 2>&1
+if [ $? -gt 0 ];then
+    echo "User: ${USER_NAME} not exists!" 
+    exit 2
+fi
+
+INSTALL_DIR=$(su - ${USER_NAME} -c "env | grep GBASEDBTDIR")
+INSTALL_DIR=${INSTALL_DIR#*=}
 su - ${USER_NAME} -c "onmode -ky"
 su - ${USER_NAME} -c "onclean -ky"
 ps -ef | awk '/oninit/ && $3==1{print "kill -9 "$2}' | sh
